package com.perforce.p4simulink;

/**
 * Perforce SCM Integration
 */

import com.mathworks.cmlink.api.ApplicationInteractor;
import com.mathworks.cmlink.api.ConfigurationManagementException;
import com.mathworks.cmlink.api.version.r14a.CMAdapter;
import com.mathworks.cmlink.api.version.r14a.CMAdapterFactory;
import com.mathworks.cmlink.api.version.r14a.CMRepository;
import com.perforce.p4simulink.connection.Config;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.io.File;
import java.nio.file.Path;

public class P4AdapterFactory implements CMAdapterFactory {

    private static final Logger log = LogManager.getLogger(P4AdapterFactory.class.getName());
    private Config config;

    @Override
    public boolean isDirSandboxForThisAdapter(File file) {
        if (file == null) {
            return false;
        }

        config = new Config();
        log.info("Checking {}", file.getAbsolutePath());
        //	Walk up through the file tree looking for a Perforce config file.  If we find one,
        // then we assume that the sandbox is under Perforce control.  If we make it to the root of the filesystem
        // and haven't found a config file, then we'll just return false and assume that it's currently outside
        // Perforce control.
        Path path = file.toPath();
        while (path != null) {
            if (config.exists(path)) {
                return true;
            } else {
                path = path.getParent();
            }
        }
        return false;
    }

    @Override
    public CMAdapter getAdapterForThisSandboxDir(File file, ApplicationInteractor applicationInteractor) throws
            ConfigurationManagementException {
        log.trace("Constructing new P4Adapter");
        return new P4Adapter(applicationInteractor, config);
    }

    public CMAdapter getAdapterForThisSandboxDir(File file, ApplicationInteractor applicationInteractor, Config config) throws
    	ConfigurationManagementException {
    		log.trace("Constructing new P4Adapter");
    		this.config = config;
    		return new P4Adapter(applicationInteractor, this.config);
    }
    
    @Override
    public CMRepository getRepository(ApplicationInteractor applicationInteractor) {
        log.trace("Constructing new P4Repository");
        return null;
    }

    @Override
    public String getName() {
        return "P4Simulink";
    }

    @Override
    public String getDescription() {
        return "Perforce SCM Integration for Simulink";
    }

}
